# Developer Environments

A number of development environments have been set up, adapted to different tasks.  The development environments provide many additional functionalities related to the core system, including those functionalities that are present in the [WARA PS tutorials](https://aiics.waraps.org/index.php/lrs-lrs_portal-notebook_instructions-introduction-md/).  

- The tutorial link requires a special account; contact +++++++++++++++)
- To ask questions about the development environment, contact `lrs-devenv@groups.liu.se`.

Please note that the instructions for the development environments are written for developers.  They do not necessarily explain every step in detail and have not necessarily been tested on every combination of hardware, operating system, software setup and so on.  You are welcome to contact us at `lrs-devenv@groups.liu.se` for assistance in troubleshooting problems that may arise or to discuss various functionalities in the development environments. 

## Installation and Configuration

To install and configure a development environment, follow these steps:

- [Ensure that you have a supported operating system](doc/install_os.md), directly on your hardware or in a virtual machine

- [Install local software on your development system](doc/install_playbooks.md), using Ansible Playbooks to automate the installation of various packages and repositories

- [Install Nvidia Docker drivers](doc/docker_nvidia.md) for 3D acceleration, if you have an Nvidia graphics card and you are not using a virtual machine

- [Install the Development Docker Image](doc/docker_devenv_image.md) containing the Docker-based Development Environment

## Interacting with the Development Docker Container

The following document shows some general examples for interfacing between the Development System and the Development Docker Container.

- [Interfacing to LRS Development Docker Modules](doc/docker_interfacing.md)

## Development Environment Instructions

For more information on how to integrate your code we have split the information in different sub-areas:

- [Development Environment: Gränsö](https://gitlab.liu.se/lrs/lrs_devenv_granso/-/blob/master/README.md): Sensor simulation in Gränsö for DJI, MQTT interface also to images
- [Development Environment: Control](https://gitlab.liu.se/lrs/lrs_devenv_control/-/blob/master/README.md)
- [Development Environment: Motion Planning](https://gitlab.liu.se/lrs/lrs_devenv_motion_planning/-/blob/master/README.md)
- [Development Environment: Task Planning](https://gitlab.liu.se/lrs/lrs_devenv_task_planning/-/blob/master/README.md)


##### Contact information

To ask questions about the development environment, contact `lrs-devenv@groups.liu.se`.